#ifndef _SELECT_H
#define _SELECT_H

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#define N 16
#define NOSTRING -2
#define INVALIDSTRING -3
#define OUTOFRANGE -4

int select_option(char options[][N], int nopt);

#endif /* _SELECT_H */
